#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Jun 19 20:53:10 2017

@author: zhangliyun
"""

"""这是“nester.py“模块，提供了一个名为print_lol的函数，这个函数的作用是打印列表，其中有可能
    包含（也可能不包含）嵌套列表"""
            
def print_lol(the_list,level):
    """这个函数取一个位置参数，名为“the_list，这可以是任何python列表（也可以是包含嵌套列表
        的列表）。所指定的列表中的每个数据项会（递归的）输出到屏幕上，各数据项各占一行。"""
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol(each_item,level+1)
        else:
            for tab_stop in range(level):
                print("\t",end='')
            print (each_item)
            



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Jun 19 21:02:47 2017

@author: zhangliyun
"""

from distutils.core import setup

setup(
        name = 'nester_typ',
        version = '1.1.0',
        py_modules = ['nester'],
        author = 'typ229870147',
        author_email = '867775486@qq.com',
        url = 'http://www.headfirstlabs.com',
        description = 'A simple printer of nested lists',
        )
